@@ -20,10 +20,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 """
 
-__version__ = '0.1.1'
+__version__ = '0.2.0'
 
 
 import functools
+import collections
 
 from timeit import default_timer
 
@@ -96,10 +97,11 @@ def timer(*func_or_func_args, **kwargs):
         def wrapped(*args, **kwargs):
             with Timer(**timer_kwargs) as t:
                 out = f(*args, **kwargs)
-            print u"function %s execution time: %.3f " % (f.__name__, t.elapsed)
+            print("function %s execution time: %.3f " % (f.__name__, t.elapsed))
             return out
         return wrapped
-    if len(func_or_func_args) == 1 and callable(func_or_func_args[0]):
+    if (len(func_or_func_args) == 1
+        and isinstance(func_or_func_args[0], collections.Callable)):
         return wrapped_f(func_or_func_args[0])
     else:
         return wrapped_f
